//
// Copyright (c) 2016, MindFusion LLC - Bulgaria.
//

using System;
using System.Drawing;
using System.Windows.Forms;


namespace MindFusion.Scheduling.WinForms.Samples.CS.Resources
{
	/// <summary>
	/// Summary description for ResourceForm.
	/// </summary>
	public partial class ResourceForm : System.Windows.Forms.Form
	{
		/// <summary>
		/// Initializes a new instance of the ResourceForm class.
		/// </summary>
		public ResourceForm(Calendar calendar, Item item)
		{
			InitializeComponent();

			// Initialize contacts combo
			_person.Items.Clear();

			foreach (Contact contact in calendar.Contacts)
				_person.Items.Add(contact.FirstName + " " + contact.LastName);

			_calendar = calendar;
			_item = item;

			// Initialize values from the item
			if (_item != null)
			{
				_name.Text = _item.HeaderText;
				_from.Value = _item.StartTime;
				_fromTime.Value = _item.StartTime;
				_to.Value = _item.EndTime;
				_toTime.Value = _item.EndTime;

				if (_item.Contacts.Count > 0)
				{
					Contact c = _item.Contacts[0];

					for (int i = 0; i < _calendar.Contacts.Count; i++)
					{
						if (_calendar.Contacts[i] == c)
						{
							_person.SelectedIndex = i;
							break;
						}
					}
				}
			}
		}

		private void _btnOK_Click(object sender, System.EventArgs e)
		{
			if (_person.SelectedIndex == -1)
			{
				MessageBox.Show("Select person!");
				return;
			}

			// Accept changes,
			// If new item is created, add the new item to the control
			Item item = _item;

			if (item == null)
			{
				item = new Appointment();
				_calendar.Schedule.Items.Add(item);
			}

			item.HeaderText = _name.Text;
			item.StartTime = new DateTime(
				_from.Value.Year,
				_from.Value.Month,
				_from.Value.Day,
				_fromTime.Value.Hour,
				_fromTime.Value.Minute, 0);
			item.EndTime = new DateTime(
				_to.Value.Year,
				_to.Value.Month,
				_to.Value.Day,
				_toTime.Value.Hour,
				_toTime.Value.Minute, 0);

			item.Contacts.Clear();
			item.Contacts.Add(_calendar.Contacts[_person.SelectedIndex]);

			_calendar.Invalidate();

			Close();
		}

		public void Set(DateTime date, Contact c)
		{
			_from.Value = date;
			_fromTime.Value = date;
			_to.Value = date + TimeSpan.FromDays(1);
			_toTime.Value = date + TimeSpan.FromDays(1);

			for (int i = 0; i < _calendar.Contacts.Count; i++)
			{
				if (_calendar.Contacts[i] == c)
				{
					_person.SelectedIndex = i;
					break;
				}
			}
		}


		private Calendar _calendar;
		private Item _item;
	}
}
